<?php

// All functions are placed in this file...include it and call relevant functions as required

// getNewSchoolId checks the last school id in the schools table and increment it by 1
function checkSchool($name, $location){
    include 'config.php';
    $stmt = $conn->PREPARE("SELECT * FROM `schools` WHERE (`school_name`=?) AND (`school_location`=?)");
    $stmt->BIND_PARAM("ss", $name, $location);
    $stmt->EXECUTE();
    $result = $stmt->GET_RESULT();
    $stmt->close();
    if (mysqli_num_rows($result)>0){
        return false;
    }else{
        return true;
    }
    
}

// get the next id from table
function getNewSchoolId(){
    include 'config.php';
    $stmt = $conn->PREPARE("SELECT * FROM `schools`");
    $stmt->EXECUTE();
    $result = $stmt->GET_RESULT();
    if (mysqli_num_rows($result)==0){
        //no school found initialize to 100001
        $id = 100001;
    }else{
        while ($row = $result->fetch_assoc()){
            $id = $row['school_id'];
            }
        $id+=1;
    }
    $stmt->close();
    return $id;
}

// add school records to schools table - school_id, school_name, school_category required
function addSchoolInformation($id, $name, $category, $location, $address){
    include 'config.php';
    $stmt = $conn->PREPARE("INSERT INTO `schools`(`school_id`, `school_name`, `school_category`, `school_location`, `school_address`) VALUES (?,?,?,?,?)");
    $stmt->BIND_PARAM("sssss", $id, $name, $category, $location, $address);
    if ($stmt->EXECUTE()){
        $pass = true;
        $message = "School Information added to schools table successfully."."<br />"."School id is ".$id;  
    }else{
        $pass = false;
        $message = "something is wrong, could not add school information to schools table";
    };
    $stmt->close();
    return array("pass"=>$pass, "message"=>$message);
}

function removeSchoolInformation($id){
    include 'config.php';
    $stmt = $conn->PREPARE("DELETE FROM `schools` WHERE `school_id` = ?");
    $stmt->BIND_PARAM("s", $id);
    $stmt->EXECUTE();
    $stmt->close();
}

function copyDirectory($source, $target) {
    if (is_dir($source)){
        @mkdir($target);
        $d = dir($source);
        while (FALSE !== ($entry = $d->read())) {
            if ($entry == '.' || $entry == '..') {
                continue;
            }
            $Entry = $source . '/' . $entry; 
            if (is_dir($Entry)) {
                copyDirectory($Entry, $target . '/' . $entry );
                continue;
            }
            copy($Entry, $target . '/' . $entry);
        }

        $d->close();
    }else {
        copy($source, $target);
    }
}


function deldir($dir) {
  if (is_dir($dir)) {
    $objects = scandir($dir);
    foreach ($objects as $object) {
      if ($object != "." && $object != "..") {
        if (filetype($dir."/".$object) == "dir") 
           deldir($dir."/".$object); 
        else unlink   ($dir."/".$object);
      }
    }
    reset($objects);
    rmdir($dir);
  }
}

function deleteTable($name){
    include 'config.php';
    $stmt = $conn->PREPARE("DROP TABLE `$name`");
    $stmt->EXECUTE();
    $stmt->close();
}

function card01_stat(){
    //this function gets basic school stats for dashboard stat 01
        //it returns total number of schools, and their number and percentages
    include 'config.php';
    $stmt = $conn->PREPARE("SELECT `school_category` FROM `schools` WHERE `school_category` = 'pre-primary'");
    $stmt->EXECUTE();
    $result = $stmt->GET_RESULT();
    $stat[0] = mysqli_num_rows($result);
    $stmt->close();
    $stmt = $conn->PREPARE("SELECT `school_category` FROM `schools` WHERE `school_category` = 'primary'");
    $stmt->EXECUTE();
    $result = $stmt->GET_RESULT();
    $stat[1] = mysqli_num_rows($result);
    $stmt->close();
    $stmt = $conn->PREPARE("SELECT `school_category` FROM `schools` WHERE `school_category` = 'secondary'");
    $stmt->EXECUTE();
    $result = $stmt->GET_RESULT();
    $stat[2] = mysqli_num_rows($result);
    $stmt->close();
    $stmt = $conn->PREPARE("SELECT `school_category` FROM `schools` WHERE `school_category` = 'primary-and-secondary'");
    $stmt->EXECUTE();
    $result = $stmt->GET_RESULT();
    $stat[3] = mysqli_num_rows($result);
    $stmt->close();
    return $stat;
}

function card02_stat(){
    //this function gets basic student stats for dashboard stat 02
        //it returns total number of students, and their number and percentages for male/female category
    include 'config.php';
    $stmt = $conn->PREPARE("SELECT * FROM `students` WHERE `gender` = 'male'");
    $stmt->EXECUTE();
    $result = $stmt->GET_RESULT();
    $stat[0] = mysqli_num_rows($result);
    $stmt->close();
    $stmt = $conn->PREPARE("SELECT * FROM `students` WHERE `gender` = 'female'");
    $stmt->EXECUTE();
    $result = $stmt->GET_RESULT();
    $stat[1] = mysqli_num_rows($result);
    $stmt->close();
    return $stat;
}

function notify($id, $text){
    include 'config.php';
    $stmt = $conn->PREPARE("INSERT INTO `notifications`(`school_id`, `events`) VALUES (?,?)");
    $stmt->BIND_PARAM("ss", $id, $text);
    $stmt->EXECUTE();
    $stmt->close();
}

function get_notice(){
    include 'config.php';
    $stmt = $conn->PREPARE("SELECT * FROM `notifications`");
    $stmt->EXECUTE();
    $result = $stmt->GET_RESULT();
    while ($row = $result->fetch_assoc()){
        $stat[]=$row['events'];
    }
    return $stat;
}

function card03_stat(){
    //this function gets basic school stats for dashboard stat 03
        //it returns total active and inactive schools
    include 'config.php';
    $stmt = $conn->PREPARE("SELECT `school_status` FROM `schools` WHERE `school_status` = 1");
    $stmt->EXECUTE();
    $result = $stmt->GET_RESULT();
    $stat[0] = mysqli_num_rows($result);
    $stmt->close();
    $stmt = $conn->PREPARE("SELECT `school_status` FROM `schools` WHERE `school_status` = 0");
    $stmt->EXECUTE();
    $result = $stmt->GET_RESULT();
    $stat[1] = mysqli_num_rows($result);
    $stmt->close();
    return $stat;
}

function card04_stat(){
    //this function gets basic student stats for dashboard stat 04
        //it returns total active and inactive students
    include 'config.php';
    $stmt = $conn->PREPARE("SELECT `status` FROM `students` WHERE `status` = 1");
    $stmt->EXECUTE();
    $result = $stmt->GET_RESULT();
    $stat[0] = mysqli_num_rows($result);
    $stmt->close();
    $stmt = $conn->PREPARE("SELECT `status` FROM `students` WHERE `status` = 0");
    $stmt->EXECUTE();
    $result = $stmt->GET_RESULT();
    $stat[1] = mysqli_num_rows($result);
    $stmt->close();
    return $stat;
}

function getExplodeStatement($sentence){
    $query_array = explode(" ", $sentence);
    $word_count = count($query_array);
    for ($c=0; $c<$word_count; $c++){
        $build= " `student_id` LIKE ? OR `firstname` LIKE ? OR `lastname` LIKE ? OR `middlename` LIKE ? OR `school_name` LIKE ?";
        $my_statement.=$build;
        if ($c<$word_count-1){
                $my_statement.="  OR  ";
            }
        $statement_build = "SELECT *  FROM `students` WHERE ".$my_statement;
        $param.="sssss";
        //add values 5 times -- for student_id, firstname, lastname, middlename,
        for($d=0; $d<5; $d++){
           $value[] = "%".$query_array[$c]."%"; 
        }
        
        
    }
    $final_statement = $statement_build;
    return array($final_statement, $param, $value);
}

function getExplodeStatement2($sentence){
    $query_array = explode(" ", $sentence);
    $word_count = count($query_array);
    for ($c=0; $c<$word_count; $c++){
        $build= " `school_id` LIKE ? OR `school_name` LIKE ? OR `school_category` LIKE ? OR `school_location` LIKE ?";
        $my_statement.=$build;
        if ($c<$word_count-1){
                $my_statement.="  OR  ";
            }
        $statement_build = "SELECT *  FROM `schools` WHERE ".$my_statement;
        $param.="ssss";
        //add values 4 times -- for school_id, school_name, school_location, school_category,
        for($d=0; $d<4; $d++){
           $value[] = "%".$query_array[$c]."%"; 
        }
        
        
    }
    $final_statement = $statement_build;
    return array($final_statement, $param, $value);
}

function getExplodeStatement1($sentence){
    $query_array = explode(" ", $sentence);
    $word_count = count($query_array);
    for ($c=0; $c<$word_count; $c++){
        $build= " `teacher_id` LIKE ? OR `firstname` LIKE ? OR `lastname` LIKE ? OR `middlename` LIKE ?";
        $my_statement.=$build;
        if ($c<$word_count-1){
                $my_statement.="  OR  ";
            }
        $statement_build = "SELECT *  FROM `teachers` WHERE ".$my_statement;
        $param.="ssss";
        //add values 4 times -- for teacher_id, firstname, lastname, middlename,
        for($d=0; $d<4; $d++){
           $value[] = "%".$query_array[$c]."%"; 
        }
        
        
    }
    $final_statement = $statement_build;
    return array($final_statement, $param, $value);
}

function getExplodeStatement4($sentence){
    $query_array = explode(" ", $sentence);
    $word_count = count($query_array);
    for ($c=0; $c<$word_count; $c++){
        $build= " `teacher_id` LIKE ? OR `firstname` LIKE ? OR `lastname` LIKE ? OR `middlename` LIKE ? OR `school_name` LIKE ?";
        $my_statement.=$build;
        if ($c<$word_count-1){
                $my_statement.="  OR  ";
            }
        $statement_build = "SELECT *  FROM `teachers` WHERE ".$my_statement;
        $param.="sssss";
        //add values 5 times -- for teaher_id, firstname, lastname, middlename,
        for($d=0; $d<5; $d++){
           $value[] = "%".$query_array[$c]."%"; 
        }
        
        
    }
    $final_statement = $statement_build;
    return array($final_statement, $param, $value);
}


function getExplodeStatement5($sentence){
    $query_array = explode(" ", $sentence);
    $word_count = count($query_array);
    for ($c=0; $c<$word_count; $c++){
        $build= " `school_id` LIKE ? OR `school_name` LIKE ? OR `firstname` LIKE ? OR `lastname` LIKE ?";
        $my_statement.=$build;
        if ($c<$word_count-1){
                $my_statement.="  OR  ";
            }
        $statement_build = "SELECT *  FROM `school_admins` WHERE ".$my_statement;
        $param.="ssss";
        //add values 4 times -- for school_id, school_name, school_location, school_category,
        for($d=0; $d<4; $d++){
           $value[] = "%".$query_array[$c]."%"; 
        }
        
        
    }
    $final_statement = $statement_build;
    return array($final_statement, $param, $value);
}

function getExplodeStatement6($sentence){
    $query_array = explode(" ", $sentence);
    $word_count = count($query_array);
    for ($c=0; $c<$word_count; $c++){
        $build= " `student_id` LIKE ? OR `firstname` LIKE ? OR `lastname` LIKE ? OR `school_name` LIKE ?";
        $my_statement.=$build;
        if ($c<$word_count-1){
                $my_statement.="  OR  ";
            }
        $statement_build = "SELECT *  FROM `parents` WHERE ".$my_statement;
        $param.="ssss";
        //add values 5 times -- for student_id, firstname, lastname, middlename,
        for($d=0; $d<4; $d++){
           $value[] = "%".$query_array[$c]."%"; 
        }
        
        
    }
    $final_statement = $statement_build;
    return array($final_statement, $param, $value);
}

function getReceiver($id){
    include 'config.php';
    //determine length of ID - admin(6) or student/teacher(14)
    $count = strlen($id);
    if ($count==6){
        //search admin table
        $stmt = $conn->PREPARE("SELECT * FROM `school_admins` WHERE `school_id` = ?");
            $stmt->BIND_PARAM("s", $id);
            $stmt->EXECUTE();
            $result = $stmt->GET_RESULT();
            while ($row = $result->fetch_assoc()){
                $receiver = ucwords($row['school_name'])." Admin";
                return $receiver;
            }
    }
    
}
?>



